@@ -1,7 +1,7 @@
 /*
  * transition_frei0r.c -- frei0r transition
  * Copyright (c) 2008 Marco Gittler <g.marco@freenet.de>
- * Copyright (C) 2009-2019 Meltytech, LLC
+ * Copyright (C) 2009-2020 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -41,6 +41,8 @@ static int transition_get_image( mlt_frame a_frame, uint8_t **image, mlt_image_f
 	mlt_properties b_props = MLT_FRAME_PROPERTIES( b_frame );
 	int invert = mlt_properties_get_int( properties, "invert" );
 	uint8_t *images[] = {NULL, NULL, NULL};
+	int request_width = *width;
+	int request_height = *height;
 	int error = 0;
 
 	// Get the B-frame.
@@ -48,6 +50,14 @@ static int transition_get_image( mlt_frame a_frame, uint8_t **image, mlt_image_f
 	error = mlt_frame_get_image( b_frame, &images[1], format, width, height, 0 );
 	if ( error ) return error;
 
+	if (b_frame->convert_image && (*width != request_width || *height != request_height)) {
+		mlt_properties_set_int(b_props, "convert_image_width", request_width);
+		mlt_properties_set_int(b_props, "convert_image_height", request_height);
+		b_frame->convert_image(b_frame, &images[1], format, *format);
+		*width = request_width;
+		*height = request_height;
+	}
+
 	const char *service_name = mlt_properties_get(properties, "mlt_service");
 	int is_cairoblend = service_name && !strcmp("frei0r.cairoblend", service_name);
 	const char *blend_mode = mlt_properties_get(b_props, CAIROBLEND_MODE_PROPERTY);
@@ -70,6 +80,14 @@ static int transition_get_image( mlt_frame a_frame, uint8_t **image, mlt_image_f
 		error = mlt_frame_get_image( a_frame, &images[0], format, width, height, 0 );
 		if ( error ) return error;
 
+		if (a_frame->convert_image && (*width != request_width || *height != request_height)) {
+			mlt_properties_set_int(a_props, "convert_image_width", request_width);
+			mlt_properties_set_int(a_props, "convert_image_height", request_height);
+			a_frame->convert_image(a_frame, &images[0], format, *format);
+			*width = request_width;
+			*height = request_height;
+		}
+
 		mlt_position position = mlt_transition_get_position( transition, a_frame );
 		mlt_profile profile = mlt_service_profile( MLT_TRANSITION_SERVICE( transition ) );
 		double time = (double) position / mlt_profile_fps( profile );
