@@ -20,7 +20,6 @@
 #define __STDC_FORMAT_MACROS  /* see inttypes.h */
 #define __STDC_LIMIT_MACROS
 #define __STDC_CONSTANT_MACROS
-#define _XOPEN_SOURCE
 
 #include <stdint.h>
 #include <inttypes.h>
@@ -38,38 +37,40 @@
 
 #include "factory.h"
 
+#define NDI_TIMEBASE 10000000LL
+
 typedef struct
 {
-	struct mlt_producer_s parent;
+	mlt_producer parent;
 	int f_running, f_exit, f_timeout;
 	char* arg;
 	pthread_t th;
 	int count;
-	mlt_slices sliced_swab;
 	mlt_deque a_queue, v_queue;
 	pthread_mutex_t lock;
 	pthread_cond_t cond;
 	NDIlib_recv_instance_t recv;
-	int v_queue_limit, a_queue_limit;
+	int v_queue_limit, a_queue_limit, v_prefill;
 } producer_ndi_t;
 
 static void* producer_ndi_feeder( void* p )
 {
-	int i;
 	mlt_producer producer = p;
+	int ndi_src_idx;
 	const NDIlib_source_t* ndi_srcs = NULL;
 	NDIlib_video_frame_t* video = NULL;
-	NDIlib_audio_frame_t* audio = NULL;
-	NDIlib_metadata_frame_t* meta = NULL;
+	NDIlib_audio_frame_t audio;
+	NDIlib_metadata_frame_t meta;
 	producer_ndi_t* self = ( producer_ndi_t* )producer->child;
 
 	mlt_log_debug( MLT_PRODUCER_SERVICE(producer), "%s: entering\n", __FUNCTION__ );
 
 	// find the source
-	const NDIlib_find_create_t find_create_desc = { true, NULL };
+	const NDIlib_find_create_t find_create_desc = { .show_local_sources = true,
+		.p_groups = NULL, .p_extra_ips = NULL };
 
 	// create a finder
-	NDIlib_find_instance_t ndi_find = NDIlib_find_create( &find_create_desc );
+	NDIlib_find_instance_t ndi_find = NDIlib_find_create2( &find_create_desc );
 	if ( !ndi_find )
 	{
 		mlt_log_error( MLT_PRODUCER_SERVICE( producer ), "%s: NDIlib_find_create failed\n", __FUNCTION__ );
@@ -77,31 +78,34 @@ static void* producer_ndi_feeder( void* p )
 	}
 
 	// wait for source
-	mlt_log_debug( MLT_PRODUCER_SERVICE( producer ), "%s: waiting for source [%s]\n", __FUNCTION__, self->arg );
-	for ( i = -1; !self->f_exit && -1 == i; )
+	mlt_log_debug( MLT_PRODUCER_SERVICE( producer ), "%s: waiting for sources, searching for [%s]\n",
+		__FUNCTION__, self->arg );
+	for ( ndi_src_idx = -1; ndi_src_idx == -1 && !self->f_exit; )
 	{
-		int c = 0, j;
+		unsigned int j, f, n;
 
-		// wait for sources
-		ndi_srcs = NDIlib_find_get_sources( ndi_find, &c, 100 );
-
-		// check if requested src found
-		for ( j = 0; j < c && -1 == i; j++ )
-			if ( !strcmp( self->arg, ndi_srcs[j].p_ndi_name ) )
-				i = j;
-
-		// free if not found
-		if ( -1 == i && ndi_srcs )
+		// wait sources list changed
+		f = NDIlib_find_wait_for_sources( ndi_find, 500 );
+		mlt_log_debug( MLT_PRODUCER_SERVICE( producer ), "%s: NDIlib_find_wait_for_sources=%d\n", __FUNCTION__, f );
+		if ( !f )
 		{
-			ndi_srcs = NULL;
+			mlt_log_debug( MLT_PRODUCER_SERVICE( producer ), "%s: no more sources\n", __FUNCTION__ );
+			break;
 		}
+
+		// check if request present in sources list
+		ndi_srcs = NDIlib_find_get_current_sources( ndi_find, &n );
+		mlt_log_debug( MLT_PRODUCER_SERVICE( producer ), "%s: found %d sources\n", __FUNCTION__, n );
+		for ( j = 0; j < n && ndi_src_idx == -1; j++ )
+			if ( !strcmp( self->arg, ndi_srcs[j].p_ndi_name ) )
+				ndi_src_idx = j;
 	}
 
 	// exit if nothing
-	if ( self->f_exit || -1 == i )
+	if ( self->f_exit || ndi_src_idx == -1 )
 	{
-		mlt_log_error( MLT_PRODUCER_SERVICE( producer ), "%s: exiting, self->f_exit=%d, i=%d\n",
-			__FUNCTION__, self->f_exit, i );
+		mlt_log_error( MLT_PRODUCER_SERVICE( producer ), "%s: exiting, self->f_exit=%d\n",
+			__FUNCTION__, self->f_exit );
 
 		NDIlib_find_destroy( ndi_find );
 
@@ -113,8 +117,8 @@ static void* producer_ndi_feeder( void* p )
 	// create receiver description
 	NDIlib_recv_create_t recv_create_desc =
 	{
-		ndi_srcs[ i ],
-		NDIlib_recv_color_format_UYVY_BGRA,
+		ndi_srcs[ ndi_src_idx ],
+		NDIlib_recv_color_format_e_UYVY_RGBA,
 		NDIlib_recv_bandwidth_highest,
 		true
 	};
@@ -136,17 +140,14 @@ static void* producer_ndi_feeder( void* p )
 	while( !self->f_exit )
 	{
 		NDIlib_frame_type_e t;
+		NDIlib_audio_frame_interleaved_16s_t *audio_packet, *audio_packet_prev;
 
 		if ( !video )
 			video = mlt_pool_alloc( sizeof( NDIlib_video_frame_t ) );
-		if ( !audio )
-			audio = mlt_pool_alloc( sizeof( NDIlib_audio_frame_t ) );
-		if ( !meta )
-			meta = mlt_pool_alloc( sizeof( NDIlib_metadata_frame_t ) );
 
-////fprintf(stderr, "%s:%d: NDIlib_recv_capture....\n", __FUNCTION__, __LINE__ );
-		t = NDIlib_recv_capture(self->recv, video, audio, meta, 10 );
-////fprintf(stderr, "%s:%d: NDIlib_recv_capture=%d\n", __FUNCTION__, __LINE__, t );
+		t = NDIlib_recv_capture(self->recv, video, &audio, &meta, 10 );
+
+		mlt_log_debug( NULL, "%s:%d: NDIlib_recv_capture=%d\n", __FILE__, __LINE__, t );
 
 		switch( t )
 		{
@@ -154,9 +155,7 @@ static void* producer_ndi_feeder( void* p )
 				break;
 
 			case NDIlib_frame_type_video:
-////fprintf(stderr, "%s:%d: locking....\n", __FUNCTION__, __LINE__ );
 				pthread_mutex_lock( &self->lock );
-////fprintf(stderr, "%s:%d: locked\n", __FUNCTION__, __LINE__ );
 				mlt_deque_push_back( self->v_queue, video );
 				if ( mlt_deque_count( self->v_queue ) >= self->v_queue_limit )
 				{
@@ -167,28 +166,70 @@ static void* producer_ndi_feeder( void* p )
 					video = NULL;
 				pthread_cond_broadcast( &self->cond );
 				pthread_mutex_unlock( &self->lock );
-////fprintf(stderr, "%s:%d: unlocked\n", __FUNCTION__, __LINE__ );
 				break;
 
 			case NDIlib_frame_type_audio:
-////fprintf(stderr, "%s:%d: locking....\n", __FUNCTION__, __LINE__ );
+				// convert to 16s interleaved
+				audio_packet = mlt_pool_alloc( sizeof( NDIlib_audio_frame_interleaved_16s_t ) );
+				audio_packet->reference_level = 0;
+				audio_packet->p_data = mlt_pool_alloc( 2 * audio.no_channels * audio.no_samples );
+				NDIlib_util_audio_to_interleaved_16s( &audio, audio_packet );
+				NDIlib_recv_free_audio( self->recv, &audio );
+
+				// store into queue
 				pthread_mutex_lock( &self->lock );
-////fprintf(stderr, "%s:%d: locked\n", __FUNCTION__, __LINE__ );
-				mlt_deque_push_back( self->a_queue, audio );
+
+				// check if it continues prev packet
+				audio_packet_prev = mlt_deque_pop_back( self->a_queue );
+				if ( audio_packet_prev )
+				{
+					int64_t
+						n = audio_packet_prev->timecode +
+							NDI_TIMEBASE * audio_packet_prev->no_samples /
+								audio_packet_prev->sample_rate,
+						d = audio_packet->timecode - n;
+
+					if ( d && llabs( d ) < 2 )
+					{
+						mlt_log_debug( NULL, "%s:%d: audio_packet_prev->timecode=%"PRId64", audio_packet->timecode=%"PRId64", n=%"PRId64", d=%"PRId64", audio_packet_prev->no_samples=%d\n",
+							__FILE__, __LINE__, audio_packet_prev->timecode,
+							audio_packet->timecode, n ,d, audio_packet_prev->no_samples );
+
+						audio_packet_prev->p_data = mlt_pool_realloc( audio_packet_prev->p_data,
+							( audio_packet_prev->no_samples + audio_packet->no_samples ) *
+							audio_packet->no_channels * 2);
+
+						memcpy
+						(
+							(unsigned char*)audio_packet_prev->p_data +
+							2 * audio_packet_prev->no_channels * audio_packet_prev->no_samples,
+							audio_packet->p_data,
+							2 * audio_packet->no_channels * audio_packet->no_samples
+						);
+
+						audio_packet_prev->no_samples += audio_packet->no_samples;
+
+						mlt_pool_release( audio_packet->p_data );
+						mlt_pool_release( audio_packet );
+						audio_packet = NULL;
+					}
+
+					mlt_deque_push_back( self->a_queue, audio_packet_prev );
+				}
+				if ( audio_packet )
+					mlt_deque_push_back( self->a_queue, audio_packet );
 				if ( mlt_deque_count( self->a_queue ) >= self->a_queue_limit )
 				{
-					audio = mlt_deque_pop_front( self->a_queue );
-					NDIlib_recv_free_audio( self->recv, audio );
+					audio_packet = mlt_deque_pop_front( self->a_queue );
+					mlt_pool_release( audio_packet->p_data );
+					mlt_pool_release( audio_packet );
 				}
-				else
-					audio = NULL;
 				pthread_cond_broadcast( &self->cond );
 				pthread_mutex_unlock( &self->lock );
-////fprintf(stderr, "%s:%d: unlocked\n", __FUNCTION__, __LINE__ );
 				break;
 
 			case NDIlib_frame_type_metadata:
-				NDIlib_recv_free_metadata( self->recv, meta );
+				NDIlib_recv_free_metadata( self->recv, &meta );
 				break;
 
 			case NDIlib_frame_type_error:
@@ -200,10 +241,6 @@ static void* producer_ndi_feeder( void* p )
 
 	if ( video )
 		mlt_pool_release( video );
-	if ( audio )
-		mlt_pool_release( audio );
-	if ( meta )
-		mlt_pool_release( meta );
 
 	mlt_log_debug( MLT_PRODUCER_SERVICE(producer), "%s: exiting\n", __FUNCTION__ );
 
@@ -214,29 +251,20 @@ static int get_audio( mlt_frame frame, int16_t **buffer, mlt_audio_format *forma
 {
 	mlt_properties fprops = MLT_FRAME_PROPERTIES( frame );
 	NDIlib_recv_instance_t recv = mlt_properties_get_data( fprops, "ndi_recv", NULL );
-	NDIlib_audio_frame_t* audio = mlt_properties_get_data( fprops, "ndi_audio", NULL );
+	NDIlib_audio_frame_interleaved_16s_t* audio = mlt_properties_get_data( fprops, "ndi_audio", NULL );
 
-	mlt_log_debug( NULL, "%s: recv=%p, audio=%p\n", __FUNCTION__, recv, audio );
+	mlt_log_debug( NULL, "%s:%d: recv=%p, audio=%p\n", __FILE__, __LINE__, recv, audio );
 
 	if ( recv && audio )
 	{
 		size_t size;
-		NDIlib_audio_frame_interleaved_16s_t dst;
-
 		*format = mlt_audio_s16;
 		*frequency = audio->sample_rate;
 		*channels = audio->no_channels;
 		*samples = audio->no_samples;
-
 		size = 2 * ( *samples ) * ( *channels );
-		*buffer = mlt_pool_alloc( size );
-		mlt_frame_set_audio( frame, (uint8_t*) *buffer, *format, size, (mlt_destructor)mlt_pool_release );
-
-		dst.reference_level = 0;
-		dst.p_data = *buffer;
-		NDIlib_util_audio_to_interleaved_16s( audio, &dst );
-
-		NDIlib_recv_free_audio( recv, audio );
+		*buffer = audio->p_data;
+		mlt_frame_set_audio( frame, (uint8_t*) *buffer, *format, size, NULL );
 	}
 
 	return 0;
@@ -248,7 +276,7 @@ static int get_image( mlt_frame frame, uint8_t **buffer, mlt_image_format *forma
 	NDIlib_recv_instance_t recv = mlt_properties_get_data( fprops, "ndi_recv", NULL );
 	NDIlib_video_frame_t* video = mlt_properties_get_data( fprops, "ndi_video", NULL );
 
-	mlt_log_debug( NULL, "%s: recv=%p, video=%p\n", __FUNCTION__, recv, video );
+	mlt_log_debug( NULL, "%s:%d: recv=%p, video=%p\n", __FILE__, __LINE__, recv, video );
 
 	if ( recv && video )
 	{
@@ -264,7 +292,7 @@ static int get_image( mlt_frame frame, uint8_t **buffer, mlt_image_format *forma
 			dst_stride = 2 * video->xres;
 			*format = mlt_image_yuv422;
 		}
-		else if ( NDIlib_FourCC_type_BGRA == video->FourCC )
+		else if ( NDIlib_FourCC_type_RGBA == video->FourCC || NDIlib_FourCC_type_RGBX == video->FourCC )
 		{
 			dst_stride = 4 * video->xres;
 			*format = mlt_image_rgb24a;
@@ -282,7 +310,7 @@ static int get_image( mlt_frame frame, uint8_t **buffer, mlt_image_format *forma
 		if ( NDIlib_FourCC_type_UYVY == video->FourCC  || NDIlib_FourCC_type_UYVA == video->FourCC )
 			for( j = 0; j < video->yres; j++)
 				swab2( video->p_data + j * video->line_stride_in_bytes, dst + j * dst_stride, stride );
-		else if ( NDIlib_FourCC_type_BGRA == video->FourCC )
+		else if ( NDIlib_FourCC_type_RGBA == video->FourCC || NDIlib_FourCC_type_RGBX == video->FourCC )
 			for( j = 0; j < video->yres; j++)
 				memcpy( dst + j * dst_stride, video->p_data + j * video->line_stride_in_bytes, stride );
 
@@ -307,7 +335,10 @@ static int get_image( mlt_frame frame, uint8_t **buffer, mlt_image_format *forma
 			mlt_frame_set_alpha( frame, (uint8_t*) dst, size, (mlt_destructor)mlt_pool_release );
 		}
 
-		mlt_properties_set_int( fprops, "progressive", video->frame_format_type );
+		mlt_properties_set_int( fprops, "progressive",
+			( video->frame_format_type == NDIlib_frame_format_type_progressive ) );
+		mlt_properties_set_int( fprops, "top_field_first",
+			( video->frame_format_type == NDIlib_frame_format_type_interleaved ) );
 
 		NDIlib_recv_free_video( recv, video );
 	}
@@ -318,22 +349,19 @@ static int get_image( mlt_frame frame, uint8_t **buffer, mlt_image_format *forma
 static int get_frame( mlt_producer producer, mlt_frame_ptr pframe, int index )
 {
 	mlt_frame frame = NULL;
-	NDIlib_audio_frame_t* audio = NULL;
+	NDIlib_audio_frame_interleaved_16s_t* audio_frame = NULL;
 	NDIlib_video_frame_t* video = NULL;
 	double fps = mlt_producer_get_fps( producer );
 	mlt_position position = mlt_producer_position( producer );
-	mlt_properties properties = MLT_CONSUMER_PROPERTIES( producer );
 	producer_ndi_t* self = ( producer_ndi_t* )producer->child;
 
 	pthread_mutex_lock( &self->lock );
 
+	mlt_log_debug( NULL, "%s:%d: entering %s\n", __FILE__, __LINE__, __FUNCTION__ );
+
 	// run thread
 	if ( !self->f_running )
 	{
-		if ( !self->sliced_swab && mlt_properties_get( properties, "sliced_swab" )
-			&& mlt_properties_get_int( properties, "sliced_swab" ) )
-			self->sliced_swab = mlt_slices_init(0, SCHED_FIFO, sched_get_priority_max( SCHED_FIFO ) );
-
 		// set flags
 		self->f_exit = 0;
 
@@ -343,70 +371,106 @@ static int get_frame( mlt_producer producer, mlt_frame_ptr pframe, int index )
 		self->f_running = 1;
 	}
 
-	while ( !self->f_exit ) //&& !mlt_deque_count( self->queue ) )
+	mlt_log_debug( NULL, "%s:%d: audio_cnt=%d, video_cnt=%d\n", __FILE__, __LINE__,
+		mlt_deque_count( self->a_queue ), mlt_deque_count( self->v_queue ));
+
+	// wait for prefill
+	if ( mlt_deque_count( self->v_queue ) < self->v_prefill )
 	{
-////fprintf(stderr, "%s:%d: audio=%p, video=%p, audio_cnt=%d, video_cnt=%d\n",
-////__FUNCTION__, __LINE__, audio, video,  mlt_deque_count( self->a_queue ), mlt_deque_count( self->v_queue ));
+		struct timespec tm;
 
-		if ( !video )
-			video = (NDIlib_video_frame_t*)mlt_deque_pop_front( self->v_queue );
+		// Wait
+		clock_gettime(CLOCK_REALTIME, &tm);
+		tm.tv_nsec += self->v_prefill * 1000000000LL / fps;
+		tm.tv_sec += tm.tv_nsec / 1000000000LL;
+		tm.tv_nsec %= 1000000000LL;
+		pthread_cond_timedwait( &self->cond, &self->lock, &tm );
+	}
 
-		if ( !video )
+	// pop frame to use
+	if ( mlt_deque_count( self->v_queue ) >= self->v_prefill )
+		video = (NDIlib_video_frame_t*)mlt_deque_pop_front( self->v_queue );
+
+	if ( video )
+	{
+		int64_t video_timecode_out, video_dur;
+
+		mlt_log_debug( NULL, "%s:%d: video: timecode=%"PRId64"\n",
+			__FILE__, __LINE__, video->timecode );
+		video_dur = NDI_TIMEBASE * video->frame_rate_D / video->frame_rate_N;
+		video_timecode_out = video->timecode + video_dur;
+
+		// deal with audio
+		while ( 1 )
 		{
-			int r;
-			uint64_t usec;
-			struct timeval now;
-			struct timespec tm;
+			NDIlib_audio_frame_interleaved_16s_t* audio_packet;
+			int64_t audio_packet_dur, audio_packet_timecode_out,
+				T1, T2, dst_offset, src_offset, duration;
 
-			// Wait up to half frame duration
-			gettimeofday( &now, NULL );
-			usec = now.tv_sec * 1000000 + now.tv_usec;
-			usec += 500000LL / fps;
-			tm.tv_sec = usec / 1000000LL;
-			tm.tv_nsec = (usec % 1000000LL) * 1000LL;
+			// pop audio packet
+			audio_packet = ( NDIlib_audio_frame_interleaved_16s_t* )mlt_deque_pop_front( self->a_queue );
 
-////fprintf(stderr, "%s:%d: pthread_cond_timedwait...\n", __FUNCTION__, __LINE__ );
-			r = pthread_cond_timedwait( &self->cond, &self->lock, &tm );
-////fprintf(stderr, "%s:%d: pthread_cond_timedwait=%d\n", __FUNCTION__, __LINE__, r );
-
-			continue;
-		}
-
-		if ( !audio )
-			audio = (NDIlib_audio_frame_t*)mlt_deque_pop_front( self->a_queue );
-
-		if ( !audio )
-		{
-			// send muted video frame
-//			if( mlt_deque_count( self->v_queue ) )
+			// check if audio present
+			if ( !audio_packet )
 				break;
 
-			// push back video frame
-//			mlt_deque_push_front( self->v_queue, video );
-//			video = NULL;
-		}
-		else
-		{
-			// drop audio frame
-			if ( audio->timecode < video->timecode )
+			// check if packet in a future
+			if ( video_timecode_out < audio_packet->timecode)
 			{
-				NDIlib_recv_free_audio( self->recv, audio );
-				mlt_pool_release( audio );
-				audio = NULL;
+				// push it back to queue
+				mlt_deque_push_front( self->a_queue, audio_packet );
+				break;
+			}
+
+			// calc packet
+			audio_packet_dur = NDI_TIMEBASE * audio_packet->no_samples / audio_packet->sample_rate;
+			audio_packet_timecode_out = audio_packet_dur + audio_packet->timecode;
+
+			// check if packet in the past
+			if ( audio_packet_timecode_out < video->timecode )
+			{
+				mlt_pool_release( audio_packet->p_data );
+				mlt_pool_release( audio_packet );
 				continue;
 			}
 
-			// send muted video frame, but save current audio chunk
-			if ( audio->timecode > video->timecode )
+			// allocate new audio frame
+			if ( !audio_frame )
 			{
-				mlt_deque_push_front( self->a_queue, audio );
-				audio = NULL;
+				audio_frame = ( NDIlib_audio_frame_interleaved_16s_t* )mlt_pool_alloc
+					( sizeof( NDIlib_audio_frame_interleaved_16s_t ) );
+				audio_frame->timecode = video->timecode;
+				audio_frame->no_channels = audio_packet->no_channels;
+				audio_frame->sample_rate = audio_packet->sample_rate;
+				audio_frame->no_samples = audio_packet->sample_rate * video->frame_rate_D / video->frame_rate_N;
+				audio_frame->p_data = ( short* )mlt_pool_alloc( 2 * audio_frame->no_samples * audio_frame->no_channels );
+			}
+
+			// copy data of overlapping region
+			T1 = MAX( audio_packet->timecode, video->timecode );
+			T2 = MIN( audio_packet_timecode_out, video_timecode_out );
+			dst_offset = ( T1 - audio_frame->timecode ) * audio_frame->sample_rate / NDI_TIMEBASE;
+			src_offset = ( T1 - audio_packet->timecode ) * audio_packet->sample_rate / NDI_TIMEBASE;
+			duration = ( T2 - T1 ) * audio_frame->sample_rate / NDI_TIMEBASE;;
+
+			memcpy
+			(
+				(unsigned char*)audio_frame->p_data + 2 * audio_frame->no_channels * dst_offset,
+				(unsigned char*)audio_packet->p_data + 2 * audio_packet->no_channels * src_offset,
+				2 * audio_packet->no_channels * duration
+			);
+
+			// save packet back if it will be used later or clear it
+			if ( video_timecode_out < audio_packet_timecode_out )
+			{
+				// push it back to queue
+				mlt_deque_push_front( self->a_queue, audio_packet );
 				break;
 			}
 
-			// sync frame
-			if ( audio && audio->timecode == video->timecode )
-				break;
+			// free packet data
+			mlt_pool_release( audio_packet->p_data );
+			mlt_pool_release( audio_packet );
 		}
 	}
 
@@ -419,18 +483,18 @@ static int get_frame( mlt_producer producer, mlt_frame_ptr pframe, int index )
 
 		mlt_properties_set_data( p, "ndi_recv", (void *)self->recv, 0, NULL, NULL );
 
-////fprintf(stderr, "%s:%d: audio=%p, video=%p, audio_cnt=%d, video_cnt=%d\n",
-////__FUNCTION__, __LINE__, audio, video,  mlt_deque_count( self->a_queue ), mlt_deque_count( self->v_queue ));
-
 		if ( video )
 		{
 			mlt_properties_set_data( p, "ndi_video", (void *)video, 0, mlt_pool_release, NULL );
 			mlt_frame_push_get_image( frame, get_image );
 		}
+		else
+			mlt_log_error( NULL, "%s:%d: NO VIDEO\n", __FILE__, __LINE__ );
 
-		if ( audio )
+		if ( audio_frame )
 		{
-			mlt_properties_set_data( p, "ndi_audio", (void *)audio, 0, mlt_pool_release, NULL );
+			mlt_properties_set_data( p, "ndi_audio", (void *)audio_frame, 0, mlt_pool_release, NULL );
+			mlt_properties_set_data( p, "ndi_audio_data", (void *)audio_frame->p_data, 0, mlt_pool_release, NULL );
 			mlt_frame_push_audio( frame, (void*) get_audio );
 		}
 
@@ -468,8 +532,8 @@ static void producer_ndi_close( mlt_producer producer )
 		// dequeue audio frames
 		while( mlt_deque_count( self->a_queue ) )
 		{
-			NDIlib_audio_frame_t* audio = (NDIlib_audio_frame_t*)mlt_deque_pop_front( self->a_queue );
-			NDIlib_recv_free_audio( self->recv, audio );
+			NDIlib_audio_frame_interleaved_16s_t* audio = (NDIlib_audio_frame_interleaved_16s_t*)mlt_deque_pop_front( self->a_queue );
+			mlt_pool_release( audio->p_data );
 			mlt_pool_release( audio );
 		}
 
@@ -501,15 +565,16 @@ static void producer_ndi_close( mlt_producer producer )
  */
 mlt_producer producer_ndi_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg )
 {
-	// Allocate the consumer
+	// Allocate the producer
 	producer_ndi_t* self = ( producer_ndi_t* )calloc( 1, sizeof( producer_ndi_t ) );
+	mlt_producer parent = ( mlt_producer )calloc( 1, sizeof( *parent ) );
 
 	mlt_log_debug( NULL, "%s: entering id=[%s], arg=[%s]\n", __FUNCTION__, id, arg );
 
 	// If allocated
-	if ( self && !mlt_producer_init( &self->parent, self ) )
+	if ( self && !mlt_producer_init( parent, self ) )
 	{
-		mlt_producer parent = &self->parent;
+		self->parent = parent;
 		mlt_properties properties = MLT_CONSUMER_PROPERTIES( parent );
 
 		// Setup context
@@ -520,6 +585,7 @@ mlt_producer producer_ndi_init( mlt_profile profile, mlt_service_type type, cons
 		self->a_queue = mlt_deque_init();
 		self->v_queue_limit = 6;
 		self->a_queue_limit = 6;
+		self->v_prefill = 2;
 
 		// Set callbacks
 		parent->close = (mlt_destructor) producer_ndi_close;
