@@ -19,6 +19,7 @@
 
 #include <framework/mlt_filter.h>
 #include <framework/mlt_frame.h>
+#include <framework/mlt_profile.h>
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -77,8 +78,11 @@ static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format
 		int uduration = mlt_properties_anim_get_int( properties, "unevendevelop_duration", pos, len );
 
 		int diffpic = 0;
-		if ( delta )
+		if ( delta ) {
+			mlt_profile profile = mlt_service_profile(MLT_FILTER_SERVICE(filter));
+			delta *= mlt_profile_scale_width(profile, *width);
 			diffpic = rand() % delta * 2 - delta;
+		}
 		int brightdelta = 0;
 		if (( bdu + bdd ) != 0 )
 			brightdelta = rand() % (bdu + bdd) - bdd;
