@@ -22,7 +22,7 @@
 #include <assert.h>
 
 #include "filter_glsl_manager.h"
-#include <movit/blur_effect.h>
+#include <blur_effect.h>
 
 using namespace movit;
 
@@ -38,6 +38,11 @@ static int get_image( mlt_frame frame, uint8_t **image, mlt_image_format *format
 	GlslManager::get_instance()->unlock_service( frame );
 	*format = mlt_image_glsl;
 	int error = mlt_frame_get_image( frame, image, format, width, height, writable );
+
+	if (*width < 1 || *height < 1) {
+		return error;
+	}
+
 	radius *= mlt_profile_scale_width(profile, *width);
 	mlt_properties_set_double( properties, "_movit.parms.float.radius",
 		radius );
