@@ -37,6 +37,7 @@ extern mlt_filter filter_sepia_init( mlt_profile profile, mlt_service_type type,
 extern mlt_filter filter_spot_remover_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_text_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_filter filter_timer_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
+extern mlt_filter filter_strobe_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_producer producer_blipflash_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
 extern mlt_producer producer_count_init( const char *arg );
 extern mlt_transition transition_affine_init( mlt_profile profile, mlt_service_type type, const char *id, char *arg );
@@ -71,6 +72,7 @@ MLT_REPOSITORY
 	MLT_REGISTER( filter_type, "spot_remover", filter_spot_remover_init );
 	MLT_REGISTER( filter_type, "text", filter_text_init );
 	MLT_REGISTER( filter_type, "timer", filter_timer_init );
+	MLT_REGISTER( filter_type, "strobe", filter_strobe_init );
 	MLT_REGISTER( producer_type, "blipflash", producer_blipflash_init );
 	MLT_REGISTER( producer_type, "count", producer_count_init );
 	MLT_REGISTER( transition_type, "affine", transition_affine_init );
@@ -95,6 +97,7 @@ MLT_REPOSITORY
 	MLT_REGISTER_METADATA( filter_type, "spot_remover", metadata, "filter_spot_remover.yml" );
 	MLT_REGISTER_METADATA( filter_type, "text", metadata, "filter_text.yml" );
 	MLT_REGISTER_METADATA( filter_type, "timer", metadata, "filter_timer.yml" );
+	MLT_REGISTER_METADATA( filter_type, "strobe", metadata, "filter_strobe.yml" );
 	MLT_REGISTER_METADATA( producer_type, "blipflash", metadata, "producer_blipflash.yml" );
 	MLT_REGISTER_METADATA( producer_type, "count", metadata, "producer_count.yml" );
 	MLT_REGISTER_METADATA( transition_type, "affine", metadata, "transition_affine.yml" );
