@@ -24,17 +24,9 @@ mlt_image_format validate_format( mlt_image_format format )
 {
 	switch( format )
 	{
-	case mlt_image_rgb24a:
-	case mlt_image_rgb24:
-		return mlt_image_rgb24;
 	case mlt_image_yuv420p:
 		return mlt_image_yuv420p;
 	default:
-	case mlt_image_none:
-	case mlt_image_yuv422:
-	case mlt_image_opengl:
-	case mlt_image_glsl:
-	case mlt_image_glsl_texture:
 		return mlt_image_yuv422;
 	}
 }
@@ -47,30 +39,6 @@ VSPixelFormat mltimage_to_vsimage( mlt_image_format mlt_format, int width, int h
 {
 	switch( mlt_format )
 	{
-	case mlt_image_rgb24:
-		// Convert packed RGB24 to planar YUV444
-		// Note: vid.stab 0.98 does not seem to support PF_RGB24
-		{
-			*vs_img = mlt_pool_alloc( width * height * 3 );
-			int y, u, v, r, g, b;
-			int total = width * height + 1;
-			uint8_t* yp = *vs_img;
-			uint8_t* up = yp + ( width * height );
-			uint8_t* vp = up + ( width * height );
-
-			while( --total )
-			{
-				r = *mlt_img++;
-				g = *mlt_img++;
-				b = *mlt_img++;
-				RGB2YUV_601_SCALED(r, g, b, y, u, v);
-				*yp++ = y;
-				*up++ = u;
-				*vp++ = v;
-			}
-
-			return PF_YUV444P;
-		}
 	case mlt_image_yuv420p:
 		// This format maps with no conversion
 		{
@@ -124,27 +92,6 @@ void vsimage_to_mltimage( uint8_t* vs_img, uint8_t* mlt_img, mlt_image_format ml
 {
 	switch( mlt_format )
 	{
-	case mlt_image_rgb24:
-		// Convert packet YUV444 to packed RGB24.
-		{
-			int y, u, v, r, g, b;
-			int total = width * height + 1;
-			uint8_t* yp = vs_img;
-			uint8_t* up = yp + ( width * height );
-			uint8_t* vp = up + ( width * height );
-
-			while( --total )
-			{
-				y = *yp++;
-				u = *up++;
-				v = *vp++;
-				YUV2RGB_601_SCALED( y, u, v, r, g, b );
-				*mlt_img++ = r;
-				*mlt_img++ = g;
-				*mlt_img++ = b;
-			}
-		}
-		break;
 	case mlt_image_yuv420p:
 		// This format was never converted
 		break;
